@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2025 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_BASE_ALIGNMENT_ALGORITHM_IDS_H_
-#define _U2_BASE_ALIGNMENT_ALGORITHM_IDS_H_
+#pragma once
 
 #include <U2Core/global.h>
 
@@ -28,11 +27,17 @@ namespace U2 {
 
 class U2ALGORITHM_EXPORT BaseAlignmentAlgorithmsIds {
 public:
-    //align sequences to alignment algorithms
+    // align sequences to alignment algorithms
     static const QString ALIGN_SEQUENCES_TO_ALIGNMENT_BY_UGENE;
     static const QString ALIGN_SEQUENCES_TO_ALIGNMENT_BY_MAFFT;
+
+    /**
+     * Built-in algorithm ids for "Align selected sequences" to alignment.
+     * TODO: these are the same algorithm as 'ALIGN_SEQUENCES_TO_ALIGNMENT' but with a separate visual (action) names.
+     *  This should be changed and action names assigned in UI. The algorithm must hold only generic name: MAFFT, UGENE...
+     *  TO be fixed as a part of UGENE-7499.
+     */
+    static const QString ALIGN_SELECTED_SEQUENCES_TO_ALIGNMENT_BY_MAFFT;
 };
 
-}   //namespace
-
-#endif // _U2_BASE_ALIGNMENT_ALGORITHM_IDS_H_
+}  // namespace U2
