@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2025 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_ID_TYPES_
-#define _U2_ID_TYPES_
+#pragma once
 
 /** Application global IDs types */
 
@@ -28,17 +27,14 @@
 
 namespace U2 {
 
-
-//internal types:
+// internal types:
 INT32_ID(ServiceType);
 STRING_ID(GObjectViewFactoryId);
 
-//TODO:
+// TODO:
 typedef QString DocumentFormatId;
 typedef QString GObjectType;
 typedef QString IOAdapterId;
 typedef QString GTestFormatId;
 
-} //namespace
-
-#endif
+}  // namespace U2
