@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2025 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,9 +19,10 @@
  * MA 02110-1301, USA.
  */
 
+#include "DbiDocumentFormat.h"
+
 #include <U2Core/AppContext.h>
 #include <U2Core/AssemblyObject.h>
-#include <U2Core/Counter.h>
 #include <U2Core/DNASequenceObject.h>
 #include <U2Core/GObjectUtils.h>
 #include <U2Core/IOAdapter.h>
@@ -31,12 +32,9 @@
 #include <U2Core/U2OpStatusUtils.h>
 #include <U2Core/U2SafePoints.h>
 
-#include "DbiDocumentFormat.h"
-
 namespace U2 {
 
-DbiDocumentFormat::DbiDocumentFormat(const U2DbiFactoryId& _id, const DocumentFormatId& _formatId,
-    const QString& _formatName, const QStringList& exts, DocumentFormatFlags flags, QObject* p)
+DbiDocumentFormat::DbiDocumentFormat(const U2DbiFactoryId& _id, const DocumentFormatId& _formatId, const QString& _formatName, const QStringList& exts, DocumentFormatFlags flags, QObject* p)
     : DocumentFormat(p, _formatId, flags, exts) {
     id = _id;
     formatName = _formatName;
@@ -48,9 +46,10 @@ DbiDocumentFormat::DbiDocumentFormat(const U2DbiFactoryId& _id, const DocumentFo
     formatFlags |= DocumentFormatFlag_NoPack;
     formatFlags |= DocumentFormatFlag_NoFullMemoryLoad;
     formatFlags |= DocumentFormatFlag_DirectWriteOperations;
+    formatFlags |= DocumentFormatFlag_HasModifiableName;
 }
 
-static void renameObjectsIfNamesEqual(QList<GObject*> & objs) {
+static void renameObjectsIfNamesEqual(QList<GObject*>& objs) {
     for (int i = 0; i < objs.size(); ++i) {
         int howManyEquals = 0;
         for (int j = i + 1; j < objs.size(); ++j) {
@@ -62,84 +61,74 @@ static void renameObjectsIfNamesEqual(QList<GObject*> & objs) {
 }
 
 Document* DbiDocumentFormat::loadDocument(IOAdapter* io, const U2DbiRef& dstDbiRef, const QVariantMap& fs, U2OpStatus& os) {
-    //1. open db
-    //2. read all objects
-    //3. if there is a DEEP_COPY_OBJECT hint, all objects are cloned to the db defined by dstDbiRef
-    //3. close db
+    // 1. open db
+    // 2. read all objects
+    // 3. if there is a DEEP_COPY_OBJECT hint, all objects are cloned to the db defined by dstDbiRef
+    // 3. close db
     QString url = io->getURL().getURLString();
     U2DbiRef srcDbiRef(id, url);
     DbiConnection handle(srcDbiRef, true, os);
-    CHECK_OP(os, NULL);
+    CHECK_OP(os, nullptr);
 
     U2ObjectDbi* odbi = handle.dbi->getObjectDbi();
     QList<U2DataId> objectIds = odbi->getObjects(U2ObjectDbi::ROOT_FOLDER, 0, U2DbiOptions::U2_DBI_NO_LIMIT, os);
-    CHECK_OP(os, NULL);
-
-    QList<GObject*> objects;
-    U2EntityRef ref;
-    ref.dbiRef = srcDbiRef;
-
-    objects << prepareObjects(handle, objectIds);
+    CHECK_OP(os, nullptr);
 
+    QList<GObject*> objects = prepareObjects(handle, objectIds);
     if (fs.value(DEEP_COPY_OBJECT, false).toBool()) {
-        QList<GObject *> clonedObjects = cloneObjects(objects, dstDbiRef, fs, os);
+        QList<GObject*> clonedObjects = cloneObjects(objects, dstDbiRef, fs, os);
         qDeleteAll(objects);
-        CHECK_OP_EXT(os, qDeleteAll(clonedObjects), NULL);
+        CHECK_OP_EXT(os, qDeleteAll(clonedObjects), nullptr);
         objects = clonedObjects;
     } else {
         renameObjectsIfNamesEqual(objects);
     }
 
     QString lockReason = handle.dbi->isReadOnly() ? "The database is read-only" : "";
-    Document* d = new Document(this, io->getFactory(), io->getURL(), dstDbiRef, objects, fs, lockReason);
+    auto d = new Document(this, io->getFactory(), io->getURL(), dstDbiRef, objects, fs, lockReason);
     d->setDocumentOwnsDbiResources(false);
     d->setModificationTrack(false);
 
     return d;
 }
 
-QList<GObject *> DbiDocumentFormat::prepareObjects(DbiConnection &handle, const QList<U2DataId> &objectIds) {
-    QList<GObject *> objects;
+QList<GObject*> DbiDocumentFormat::prepareObjects(DbiConnection& handle, const QList<U2DataId>& objectIds) {
+    QList<GObject*> objects;
     U2EntityRef ref;
     ref.dbiRef = handle.dbi->getDbiRef();
 
     QMap<U2DataId, GObject*> match;
 
-    bool hasMca = false;
-
-    foreach(const U2DataId &id, objectIds) {
+    for (const U2DataId& dataId : qAsConst(objectIds)) {
         U2OpStatus2Log status;
-        ref.entityId = id;
+        ref.entityId = dataId;
 
         U2Object object;
-        handle.dbi->getObjectDbi()->getObject(object, id, status);
-        CHECK_OPERATION(!status.isCoR(), continue);
-
+        handle.dbi->getObjectDbi()->getObject(object, dataId, status);
+        CHECK_CONTINUE(!status.isCoR());
 
         if (object.visualName.isEmpty()) {
             object.visualName = "Unnamed object";
         }
 
-        GObject *gobject = GObjectUtils::createObject(ref.dbiRef, id, object.visualName);
-        CHECK_OPERATION(NULL != gobject, continue);
-        hasMca |= (gobject->getGObjectType() == GObjectTypes::MULTIPLE_CHROMATOGRAM_ALIGNMENT);
+        GObject* gobject = GObjectUtils::createObject(ref.dbiRef, dataId, object.visualName);
+        CHECK_CONTINUE(gobject != nullptr);
 
-        match[id] = gobject;
+        match[dataId] = gobject;
         objects << gobject;
     }
 
-    GRUNTIME_NAMED_CONDITION_COUNTER(tvar, cvar, hasMca, "The number of opening of the ugenedb files with Sanger data", "");
-
-    if (handle.dbi->getObjectRelationsDbi() != NULL) {
-        foreach(const U2DataId &id, match.keys()) {
+    if (handle.dbi->getObjectRelationsDbi() != nullptr) {
+        const QList<U2DataId> matchKeys = match.keys();
+        for (const U2DataId& dataId : qAsConst(matchKeys)) {
             U2OpStatus2Log status;
-            GObject* srcObj = match.value(id, NULL);
-            SAFE_POINT(srcObj != NULL, "Source object is NULL", QList<GObject *>());
+            GObject* srcObj = match.value(dataId, nullptr);
+            SAFE_POINT(srcObj != nullptr, "Source object is NULL", QList<GObject*>());
             QList<GObjectRelation> gRelations;
-            QList<U2ObjectRelation> relations = handle.dbi->getObjectRelationsDbi()->getObjectRelations(id, status);
-            foreach(const U2ObjectRelation& r, relations) {
+            QList<U2ObjectRelation> relations = handle.dbi->getObjectRelationsDbi()->getObjectRelations(dataId, status);
+            foreach (const U2ObjectRelation& r, relations) {
                 GObject* relatedObject = match[r.referencedObject];
-                if (relatedObject == NULL) {
+                if (relatedObject == nullptr) {
                     continue;
                 }
                 // SANGER_TODO: dbiId - url, should not be left like this
@@ -153,16 +142,16 @@ QList<GObject *> DbiDocumentFormat::prepareObjects(DbiConnection &handle, const
 
     return objects;
 }
-QList<GObject *> DbiDocumentFormat::cloneObjects(const QList<GObject *> &srcObjects, const U2DbiRef &dstDbiRef, const QVariantMap &hints, U2OpStatus &os) {
-    QList<GObject *> clonedObjects;
+QList<GObject*> DbiDocumentFormat::cloneObjects(const QList<GObject*>& srcObjects, const U2DbiRef& dstDbiRef, const QVariantMap& hints, U2OpStatus& os) {
+    QList<GObject*> clonedObjects;
     CHECK_EXT(dstDbiRef.isValid(), os.setError(tr("Invalid destination database reference")), clonedObjects);
 
     int number = 0;
     int total = srcObjects.size();
-    foreach(GObject *srcObject, srcObjects) {
+    foreach (GObject* srcObject, srcObjects) {
         U2OpStatusMapping mapping(number, (number + 1) / total);
         U2OpStatusChildImpl childOs(&os, mapping);
-        GObject *clonedObject = srcObject->clone(dstDbiRef, childOs, hints);
+        GObject* clonedObject = srcObject->clone(dstDbiRef, childOs, hints);
         CHECK_OP(os, clonedObjects);
         clonedObjects << clonedObject;
         number++;
@@ -183,7 +172,7 @@ void DbiDocumentFormat::storeDocument(Document* d, IOAdapter* ioAdapter, U2OpSta
     QMap<GObject*, GObject*> clonedObjects;
     QMap<GObjectReference, GObjectReference> match;
 
-    foreach(GObject *object, d->getObjects()) {
+    foreach (GObject* object, d->getObjects()) {
         if (!supportedObjectTypes.contains(object->getGObjectType())) {
             continue;
         }
@@ -194,18 +183,18 @@ void DbiDocumentFormat::storeDocument(Document* d, IOAdapter* ioAdapter, U2OpSta
             continue;
         }
 
-        GObject *resultObject = object->clone(dstDbiRef, os);
+        GObject* resultObject = object->clone(dstDbiRef, os);
         CHECK_OP(os, );
 
         clonedObjects[object] = resultObject;
-        match[GObjectReference(object, false)] = GObjectReference(url, resultObject->getGObjectName(),
-            resultObject->getGObjectType(), resultObject->getEntityRef());
+        match[GObjectReference(object, false)] = GObjectReference(url, resultObject->getGObjectName(), resultObject->getGObjectType(), resultObject->getEntityRef());
     }
 
-    foreach(GObject* initialObj, clonedObjects.keys()) {
+    foreach (GObject* initialObj, clonedObjects.keys()) {
         GObject* cloned = clonedObjects[initialObj];
         QList<GObjectRelation> relations;
-        foreach(const GObjectRelation& r, initialObj->getObjectRelations()) {
+        QList<GObjectRelation> initialRelations = initialObj->getObjectRelations();
+        for (const GObjectRelation& r : qAsConst(initialRelations)) {
             if (match.contains(r.ref)) {
                 relations << GObjectRelation(match[r.ref], r.role);
             }
@@ -219,7 +208,7 @@ void DbiDocumentFormat::storeDocument(Document* d, IOAdapter* ioAdapter, U2OpSta
 
 FormatCheckResult DbiDocumentFormat::checkRawData(const QByteArray& rawData, const GUrl& url) const {
     U2DbiFactory* f = AppContext::getDbiRegistry()->getDbiFactoryById(id);
-    if (f != NULL) {
+    if (f != nullptr) {
         QHash<QString, QString> props;
         props[U2DbiOptions::U2_DBI_OPTION_URL] = url.getURLString();
         U2OpStatusImpl os;
@@ -231,5 +220,4 @@ FormatCheckResult DbiDocumentFormat::checkRawData(const QByteArray& rawData, con
     return FormatDetection_NotMatched;
 }
 
-
-}//namespace
+}  // namespace U2
