@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2025 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,28 +19,29 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GOBJECT_TYPES_H_
-#define _U2_GOBJECT_TYPES_H_
-
-#include <U2Core/global.h>
+#pragma once
 
 #include <QIcon>
 
+#include <U2Core/global.h>
+#include <U2Core/U2IdTypes.h>
+
 namespace U2 {
 
 class U2CORE_EXPORT GObjectTypeInfo {
 public:
-    GObjectTypeInfo(){}
+    GObjectTypeInfo() {
+    }
     GObjectTypeInfo(const GObjectType& _type, const QString& _name, const QString& _pluralName, const QString& treeSign, const QString iconURL, const QString& lockedIconUrl);
 
     GObjectType type;
-    QString     name;
-    QString     pluralName;
-    QString     treeSign;
-    QString     iconURL;
-    QString     lockedIconUrl;
-    QIcon       icon;
-    QIcon       lockedIcon;
+    QString name;
+    QString pluralName;
+    QString treeSign;
+    QString iconURL;
+    QString lockedIconUrl;
+    QIcon icon;
+    QIcon lockedIcon;
 };
 
 class U2CORE_EXPORT GObjectTypes {
@@ -56,21 +57,16 @@ public:
     static const GObjectType MULTIPLE_SEQUENCE_ALIGNMENT;
     static const GObjectType PHYLOGENETIC_TREE;
     static const GObjectType BIOSTRUCTURE_3D;
-    static const GObjectType UINDEX;
     static const GObjectType ASSEMBLY;
 
     static GObjectType registerTypeInfo(const GObjectTypeInfo& ti);
 
-    //Returns reference to the type by type.
-    //WARN: Caching return value by reference is not safe -> it can be relocated if new type is registered
+    // Returns reference to the type by type.
+    // WARN: Caching return value by reference is not safe -> it can be relocated if new type is registered
     static const GObjectTypeInfo& getTypeInfo(const GObjectType& type);
 
-    static void initTypeTranslations(); //must be called only once after all translations are loaded
+    static void initTypeTranslations();  // must be called only once after all translations are loaded
     static void initTypeIcons();
-
 };
 
-}//namespace
-
-
-#endif
+}  // namespace U2
