@@ -1,7 +1,7 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2013 UniPro <ugene@unipro.ru>
- * http://ugene.unipro.ru
+ * Copyright (C) 2008-2025 UniPro <ugene@unipro.ru>
+ * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,32 +19,40 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_AUTHENTIFICATION_DIALOG_H_
-#define _U2_AUTHENTIFICATION_DIALOG_H_
+#pragma once
+
+#include <QDialog>
 
 #include <U2Core/global.h>
-#include <QtGui/QDialog>
 
-class Ui_AuthentificationDialog;
+class Ui_AuthenticationDialog;
 
 namespace U2 {
 
-class U2GUI_EXPORT AuthDialog : public QDialog {
+class AuthenticationWidget;
+
+class U2GUI_EXPORT AuthenticationDialog : public QDialog {
     Q_OBJECT
 public:
-    AuthDialog(QWidget* parent);
-    ~AuthDialog();
-    QString getUserName() const;
-    QString getPasswd() const;
-    bool    rememberAuthData() const;
+    AuthenticationDialog(const QString& text, QWidget* parent);
+    ~AuthenticationDialog();
+
+    void setLogin(const QString& login);
+    void setPassword(const QString& password);
+    void setRemembered(bool isChecked);
+
+    QString getLogin() const;
+    QString getPassword() const;
+    bool isRemembered() const;
+
+    void disableLogin();
 
 private slots:
-    void sl_onOkButtonClicked();
+    void accept() override;
 
 private:
-    Ui_AuthentificationDialog* ui;
+    Ui_AuthenticationDialog* ui;
+    AuthenticationWidget* authenticationWidget;
 };
 
-} // namespace
-
-#endif
+}  // namespace U2
