@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2018 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2025 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _DELETE_GAPS_DIALOG_
-#define _DELETE_GAPS_DIALOG_
+#pragma once
 
 #include <QDialog>
 
@@ -34,13 +33,17 @@ enum DeleteMode {
     DeleteAll
 };
 
-class DeleteGapsDialog: public QDialog {
+class DeleteGapsDialog : public QDialog {
     Q_OBJECT
 public:
     DeleteGapsDialog(QWidget* parent, int alignmentLen);
     ~DeleteGapsDialog();
-    DeleteMode getDeleteMode() const {return deleteMode;}
-    int getValue() const {return value;}
+    DeleteMode getDeleteMode() const {
+        return deleteMode;
+    }
+    int getValue() const {
+        return value;
+    }
 private slots:
     void sl_onRadioButtonClicked();
     void sl_onOkClicked();
@@ -52,6 +55,4 @@ private:
     Ui_DeleteGapsDialog* ui;
 };
 
-}
-
-#endif
+}  // namespace U2
