@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2017 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2025 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,18 +19,17 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _HI_GT_FONT_DIALOG_FILLER_H_
-#define _HI_GT_FONT_DIALOG_FILLER_H_
+#pragma once
 
 #include "utils/GTUtilsDialog.h"
 
 namespace HI {
 
 class HI_EXPORT FontDialogFiller : public Filler {
-    public:
-        FontDialogFiller(GUITestOpStatus &_os)
-            :Filler(_os, ""){}
-        void commonScenario();
-    };
-}
-#endif //_HI_GT_FONT_DIALOG_FILLER_H_
+public:
+    FontDialogFiller()
+        : Filler("") {
+    }
+    void commonScenario() override;
+};
+}  // namespace HI
