@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2025 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,11 @@
  * MA 02110-1301, USA.
  */
 
+#include "BAMDbiPlugin.h"
+
 #include <QAction>
 #include <QDir>
+#include <QFile>
 #include <QMainWindow>
 #include <QMenu>
 #include <QMessageBox>
@@ -31,16 +34,18 @@
 #include <U2Core/AppSettings.h>
 #include <U2Core/AssemblyObject.h>
 #include <U2Core/CloneObjectTask.h>
+#include <U2Core/CollectionUtils.h>
 #include <U2Core/DbiDocumentFormat.h>
 #include <U2Core/DocumentUtils.h>
+#include <U2Core/FileAndDirectoryUtils.h>
 #include <U2Core/GUrlUtils.h>
 #include <U2Core/IOAdapter.h>
 #include <U2Core/IOAdapterUtils.h>
 #include <U2Core/LoadDocumentTask.h>
 #include <U2Core/ProjectModel.h>
+#include <U2Core/QObjectScopedPointer.h>
 #include <U2Core/TaskSignalMapper.h>
 #include <U2Core/TextUtils.h>
-#include <U2Core/TmpDirChecker.h>
 #include <U2Core/U2DbiRegistry.h>
 #include <U2Core/U2OpStatusUtils.h>
 #include <U2Core/U2SafePoints.h>
@@ -51,9 +56,7 @@
 #include <U2Gui/LastUsedDirHelper.h>
 #include <U2Gui/MainWindow.h>
 #include <U2Gui/OpenViewTask.h>
-#include <U2Core/QObjectScopedPointer.h>
 
-#include "BAMDbiPlugin.h"
 #include "BAMFormat.h"
 #include "ConvertToSQLiteDialog.h"
 #include "ConvertToSQLiteTask.h"
@@ -66,30 +69,30 @@ namespace U2 {
 namespace BAM {
 
 extern "C" Q_DECL_EXPORT Plugin* U2_PLUGIN_INIT_FUNC() {
-    BAMDbiPlugin* plug = new BAMDbiPlugin();
+    auto plug = new BAMDbiPlugin();
     return plug;
 }
 
-BAMDbiPlugin::BAMDbiPlugin() : Plugin(tr("BAM format support"), tr("Interface for indexed read-only access to BAM files"))
-{
-    DocumentFormat *bamDbi = new BAMFormat();
+BAMDbiPlugin::BAMDbiPlugin()
+    : Plugin(tr("BAM format support"), tr("Interface for indexed read-only access to BAM files")) {
+    DocumentFormat* bamDbi = new BAMFormat();
     AppContext::getDocumentFormatRegistry()->registerFormat(bamDbi);
     AppContext::getDbiRegistry()->registerDbiFactory(new SamtoolsBasedDbiFactory());
 
     AppContext::getDocumentFormatRegistry()->getImportSupport()->addDocumentImporter(new BAMImporter());
 }
 
-
 //////////////////////////////////////////////////////////////////////////
 // BAM importer
-BAMImporter::BAMImporter() : DocumentImporter("bam-importer", tr("BAM/SAM file import")){
-    //prepare sorted extensions list
+BAMImporter::BAMImporter()
+    : DocumentImporter("bam-importer", tr("BAM/SAM file import")) {
+    // prepare sorted extensions list
     QSet<QString> extsSet;
     BAMFormatUtils bam;
     SAMFormat sam;
-    extsSet.unite(bam.getSupportedDocumentFileExtensions().toSet()).unite(sam.getSupportedDocumentFileExtensions().toSet());
-    QStringList exts = extsSet.toList();
-    qSort(exts);
+    extsSet.unite(toSet(bam.getSupportedDocumentFileExtensions()).unite(toSet(sam.getSupportedDocumentFileExtensions())));
+    QStringList exts = toList(extsSet);
+    std::sort(exts.begin(), exts.end());
 
     formatIds << BaseDocumentFormats::BAM << BaseDocumentFormats::SAM;
     extensions << exts;
@@ -106,37 +109,35 @@ FormatCheckResult BAMImporter::checkRawData(const QByteArray& rawData, const GUr
     SAMFormat samFormat;
     FormatCheckResult samScore = samFormat.checkRawData(rawData, url);
 
-    if (bamScore.score > samScore.score ) {
+    if (bamScore.score > samScore.score) {
         return bamScore;
     }
     samScore.properties[SAM_HINT] = true;
     return samScore;
 }
 
-DocumentProviderTask* BAMImporter::createImportTask(const FormatDetectionResult& res, bool showGui, const QVariantMap &hints) {
+DocumentProviderTask* BAMImporter::createImportTask(const FormatDetectionResult& res, bool showGui, const QVariantMap& hints) {
     bool sam = res.rawDataCheckResult.properties[SAM_HINT].toBool();
     QVariantMap fullHints(hints);
     fullHints[SAM_HINT] = sam;
     return new BAMImporterTask(res.url, showGui, fullHints);
 }
 
-
-BAMImporterTask::BAMImporterTask(const GUrl& url, bool _useGui, const QVariantMap &hints) :
-    DocumentProviderTask(tr("BAM/SAM file import: %1").arg(url.fileName()), TaskFlags_NR_FOSCOE),
-    loadInfoTask(NULL),
-    loadBamInfoTask(NULL),
-    prepareToImportTask(NULL),
-    convertTask(NULL),
-    loadDocTask(NULL),
-    isSqliteDbTransit(false),
-    useGui(_useGui),
-    sam(hints.value(SAM_HINT, false).toBool()),
-    hints(hints),
-    hintedDbiRef(hints.value(DocumentFormat::DBI_REF_HINT).value<U2DbiRef>()),
-    startTime(0)
-{
+BAMImporterTask::BAMImporterTask(const GUrl& url, bool _useGui, const QVariantMap& hints)
+    : DocumentProviderTask(tr("BAM/SAM file import: %1").arg(url.fileName()), TaskFlags_NR_FOSCOE),
+      loadInfoTask(nullptr),
+      loadBamInfoTask(nullptr),
+      prepareToImportTask(nullptr),
+      convertTask(nullptr),
+      loadDocTask(nullptr),
+      isSqliteDbTransit(false),
+      useGui(_useGui),
+      sam(hints.value(SAM_HINT, false).toBool()),
+      hints(hints),
+      hintedDbiRef(hints.value(DocumentFormat::DBI_REF_HINT).value<U2DbiRef>()),
+      startTime(0) {
     documentDescription = url.fileName();
-    loadInfoTask = new LoadInfoTask( url, sam );
+    loadInfoTask = new LoadInfoTask(url, sam);
     addSubTask(loadInfoTask);
 }
 
@@ -145,10 +146,10 @@ void BAMImporterTask::prepare() {
 }
 
 namespace {
-    QString getDirUrl(const GUrl &fileUrl) {
-        return QFileInfo(fileUrl.getURLString()).dir().absolutePath();
-    }
+QString getDirUrl(const GUrl& fileUrl) {
+    return QFileInfo(fileUrl.getURLString()).dir().absolutePath();
 }
+}  // namespace
 
 QList<Task*> BAMImporterTask::onSubTaskFinished(Task* subTask) {
     QList<Task*> res;
@@ -160,19 +161,21 @@ QList<Task*> BAMImporterTask::onSubTaskFinished(Task* subTask) {
 
     if (loadInfoTask == subTask) {
         initPrepareToImportTask();
-        CHECK(NULL != prepareToImportTask, res);
+        CHECK(prepareToImportTask != nullptr, res);
         res << prepareToImportTask;
     }
 
     else if (prepareToImportTask == subTask && prepareToImportTask->isNewURL()) {
+        // This happens if the original file wasn't sorted
+        // and PrepareToImportTask created a new sorted file
         initLoadBamInfoTask();
-        CHECK(NULL != loadBamInfoTask, res);
+        CHECK(loadBamInfoTask != nullptr, res);
         res << loadBamInfoTask;
     }
 
     else if (loadBamInfoTask == subTask || prepareToImportTask == subTask) {
         initConvertToSqliteTask();
-        CHECK(NULL != convertTask, res);
+        CHECK(convertTask != nullptr, res);
         res << convertTask;
     }
 
@@ -184,19 +187,19 @@ QList<Task*> BAMImporterTask::onSubTaskFinished(Task* subTask) {
 
     else if (!isSqliteDbTransit && convertTask == subTask) {
         initLoadDocumentTask();
-        CHECK(NULL != loadDocTask, res);
+        CHECK(loadDocTask != nullptr, res);
         res << loadDocTask;
     }
 
     else if ((isSqliteDbTransit && cloneTasks.contains(subTask))) {
         cloneTasks.removeOne(subTask);
-        CloneObjectTask *cloneTask = qobject_cast<CloneObjectTask *>(subTask);
-        SAFE_POINT_EXT(NULL != cloneTask, setError("Unexpected task type: CloneObjectTask expected"), res);
+        auto cloneTask = qobject_cast<CloneObjectTask*>(subTask);
+        SAFE_POINT_EXT(cloneTask != nullptr, setError("Unexpected task type: CloneObjectTask expected"), res);
         delete cloneTask->getSourceObject();
 
         if (cloneTasks.isEmpty()) {
             initLoadDocumentTask();
-            CHECK(NULL != loadDocTask, res);
+            CHECK(loadDocTask != nullptr, res);
             res << loadDocTask;
         }
     }
@@ -210,7 +213,7 @@ QList<Task*> BAMImporterTask::onSubTaskFinished(Task* subTask) {
 
 Task::ReportResult BAMImporterTask::report() {
     time_t totalTime = time(0) - startTime;
-    taskLog.info(QString("BAMImporter task total time is %1 sec").arg( totalTime ) );
+    taskLog.info(QString("BAMImporter task total time is %1 sec").arg(totalTime));
     return ReportResult_Finished;
 }
 
@@ -225,13 +228,13 @@ void BAMImporterTask::initPrepareToImportTask() {
         QDir().mkpath(tmpDir);
 
         const QString pattern = tmpDir + "XXXXXX.ugenedb";
-        QTemporaryFile *tempLocalDb = new QTemporaryFile(pattern, this);
+        auto tempLocalDb = new QTemporaryFile(pattern, this);
 
         tempLocalDb->open();
         const QString filePath = tempLocalDb->fileName();
         tempLocalDb->close();
 
-        SAFE_POINT_EXT(QFile::exists(filePath), setError(tr("Can't create a temporary database")), );
+        SAFE_POINT_EXT(QFile::exists(filePath), setError("Can't create a temporary database"), );
 
         localDbiRef = U2DbiRef(SQLITE_DBI_ID, filePath);
     }
@@ -252,6 +255,11 @@ void BAMImporterTask::initPrepareToImportTask() {
             convert = false;
             stateInfo.setCanceled(true);
         }
+        if (!QFile::exists(srcUrl.getURLString())) {
+            setError(tr("File %1 does not exists.").arg(srcUrl.getURLString()));
+            QMessageBox::critical(AppContext::getMainWindow()->getQMainWindow(), L10N::errorTitle(), stateInfo.getError());
+            return;
+        }
     } else if (loadInfoTask->isSam() && loadInfoTask->getInfo().getHeader().getReferences().isEmpty()) {
         convert = false;
         setError(tr("SAM cannot be converted to BAM: neither reference nor header in SAM file is present"));
@@ -259,7 +267,7 @@ void BAMImporterTask::initPrepareToImportTask() {
 
     if (convert) {
         QString dirUrl = getDirUrl(loadInfoTask->getSourceUrl());
-        if (!TmpDirChecker::checkWritePermissions(dirUrl)) {
+        if (!FileAndDirectoryUtils::isDirectoryWritable(dirUrl)) {
             const GUrl url(U2DbiUtils::ref2Url(localDbiRef));
             if (url.isLocalFile()) {
                 dirUrl = getDirUrl(url);
@@ -267,33 +275,56 @@ void BAMImporterTask::initPrepareToImportTask() {
                 dirUrl = getDirUrl(AppContext::getAppSettings()->getUserAppsSettings()->getUserTemporaryDirPath());
             }
         }
-        prepareToImportTask = new PrepareToImportTask( loadInfoTask->getSourceUrl(), loadInfoTask->isSam(), refUrl, dirUrl );
+        prepareToImportTask = new PrepareToImportTask(loadInfoTask->getSourceUrl(), loadInfoTask->isSam(), refUrl, dirUrl);
     }
 }
 
 void BAMImporterTask::initLoadBamInfoTask() {
     bool samFormat = false;
-    loadBamInfoTask = new LoadInfoTask( prepareToImportTask->getSourceUrl(), samFormat );
+    loadBamInfoTask = new LoadInfoTask(prepareToImportTask->getSourceUrl(), samFormat);
 }
 
 void BAMImporterTask::initConvertToSqliteTask() {
     bool samFormat = false;
     GUrl sourceURL;
     BAMInfo bamInfo;
-    if( prepareToImportTask->isNewURL() ) {
+    if (prepareToImportTask->isNewURL()) {
         sourceURL = loadBamInfoTask->getSourceUrl();
         bamInfo = loadBamInfoTask->getInfo();
+        if (useGui) {
+            // Using @ConvertToSQLiteDialog we could set which scaffolds we should import
+            // and should we import unmapped reads as a separate scaffold or not.
+            // This info is stored to @BAMInfo of @LoadInfoTask loadInfoTask.
+            // If the original file is not sorted, it will be sorted and saved nearby (to "ORIGINAL_NAME_sorted.bam").
+            // If the new sorted file was created, it will be processed by a new one @LoadInfoTask loadBamInfoTask.
+            // As far as this task will create its own new @BAMInfo, we have to store inforation about what scaffolds we should improt.
+            auto& bamInfoWithDialogSettings = loadInfoTask->getInfo();
+            bamInfo.setUnmappedSelected(bamInfoWithDialogSettings.isUnmappedSelected());
+            auto& currentBamSelected = bamInfo.getSelected();
+            const auto& selectedWithDialog = bamInfoWithDialogSettings.getSelected();
+            if (!selectedWithDialog.isEmpty()) {
+                // Empty list of selected scaffolds in the original file means,
+                // that this file doesn't have header (it is possible, if the original file has SAM format)
+                // Overwise, number of scaffolds in orginal and in sorted files should be equal
+                SAFE_POINT_EXT(currentBamSelected.size() == selectedWithDialog.size(),
+                               setError("Original and sorted files have different number of scaffolds"), );
+
+                for (int i = 0; i < currentBamSelected.size(); i++) {
+                    currentBamSelected[i] = selectedWithDialog[i];
+                }
+            }
+        }
     } else {
         sourceURL = prepareToImportTask->getSourceUrl();
         bamInfo = loadInfoTask->getInfo();
     }
-    convertTask = new ConvertToSQLiteTask( sourceURL, localDbiRef, bamInfo, samFormat );
+    convertTask = new ConvertToSQLiteTask(sourceURL, localDbiRef, bamInfo, samFormat);
 }
 
 void BAMImporterTask::initCloneObjectTasks() {
     QList<U2Assembly> assemblies = convertTask->getAssemblies();
-    foreach (const U2Assembly &assembly, assemblies) {
-        AssemblyObject *object = new AssemblyObject(assembly.visualName, U2EntityRef(localDbiRef, assembly.id));
+    foreach (const U2Assembly& assembly, assemblies) {
+        auto object = new AssemblyObject(assembly.visualName, U2EntityRef(localDbiRef, assembly.id));
         cloneTasks << new CloneObjectTask(object, hintedDbiRef, hints.value(DocumentFormat::DBI_FOLDER_HINT, U2ObjectDbi::ROOT_FOLDER).toString());
     }
 }
@@ -301,11 +332,11 @@ void BAMImporterTask::initCloneObjectTasks() {
 void BAMImporterTask::initLoadDocumentTask() {
     if (hints.value(BAMImporter::LOAD_RESULT_DOCUMENT, true).toBool()) {
         loadDocTask = LoadDocumentTask::getDefaultLoadDocTask(convertTask->getDestinationUrl());
-        if (loadDocTask == NULL) {
+        if (loadDocTask == nullptr) {
             setError(tr("Failed to get load task for : %1").arg(convertTask->getDestinationUrl().getURLString()));
         }
     }
 }
 
-} // namespace BAM
-} // namespace U2
+}  // namespace BAM
+}  // namespace U2
