@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2025 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -16,11 +16,10 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * MA 02110-1301, USA.wo
  */
 
-#ifndef _U2_BOWTIE_SUPPORT_H_
-#define _U2_BOWTIE_SUPPORT_H_
+#pragma once
 
 #include "U2Core/ExternalToolRegistry.h"
 
@@ -29,14 +28,10 @@ namespace U2 {
 class BowtieSupport : public ExternalTool {
     Q_OBJECT
 public:
-    BowtieSupport(const QString& id, const QString &name, const QString &path = "");
+    BowtieSupport(const QString& id);
 
-    static const QString ET_BOWTIE;
-    static const QString ET_BOWTIE_BUILD;
     static const QString ET_BOWTIE_BUILD_ID;
     static const QString ET_BOWTIE_ID;
 };
 
-} // namespace U2
-
-#endif // _U2_BOWTIE_SUPPORT_H_
+}  // namespace U2
