@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2018 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2025 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,22 +19,25 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_DIPROPERTIES_TEST_H_
-#define _U2_DIPROPERTIES_TEST_H_
+#pragma once
+
+#include <QDomElement>
+
+#include <U2Core/GObject.h>
+
+#include <U2Test/XMLTestUtils.h>
 
 #include "DIPropertiesSitecon.h"
-#include <U2Test/XMLTestUtils.h>
-#include <U2Core/GObject.h>
-#include <QDomElement>
 
 namespace U2 {
 
-class GTest_DiPropertySiteconCheckAttribs : public GTest {
+class GTest_DiPropertySiteconCheckAttribs : public XmlTest {
     Q_OBJECT
 public:
     SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_DiPropertySiteconCheckAttribs, "sitecon-check_diproperty_attrib");
 
     Task::ReportResult report();
+
 private:
     DinucleotitePropertyRegistry result;
     QString key;
@@ -43,6 +46,5 @@ private:
     int expSdev;
 };
 
-}//ns
+}  // namespace U2
 
-#endif
