@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2025 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,70 +19,78 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_USER_APP_SETTINGS_GUI_CONTROLLER_H_
-#define _U2_USER_APP_SETTINGS_GUI_CONTROLLER_H_
-
-#include <ui_UserApplicationsSettingsWidget.h>
-
-#include <U2Core/NetworkConfiguration.h>
-#include <U2Gui/AppSettingsGUI.h>
+#pragma once
 
 #include <QUrl>
 
-namespace U2 {
+#include <U2Core/NetworkConfiguration.h>
 
+#include <U2Gui/AppSettingsGUI.h>
+
+#include <ui_UserApplicationsSettingsWidget.h>
+
+namespace U2 {
 
 class UserApplicationsSettingsPageController : public AppSettingsGUIPageController {
     Q_OBJECT
 public:
-    UserApplicationsSettingsPageController(QObject* p = NULL);
+    UserApplicationsSettingsPageController(QObject* p = nullptr);
 
-    virtual AppSettingsGUIPageState* getSavedState();
+    AppSettingsGUIPageState* getSavedState() override;
 
-    virtual void saveState(AppSettingsGUIPageState* s);
+    void saveState(AppSettingsGUIPageState* s) override;
+
+    AppSettingsGUIPageWidget* createWidget(AppSettingsGUIPageState* data) override;
 
-    virtual AppSettingsGUIPageWidget* createWidget(AppSettingsGUIPageState* data);
-    
     QMap<QString, QString> translations;
 
-    const QString& getHelpPageId() const {return helpPageId;};
+    const QString& getHelpPageId() const override {
+        return helpPageId;
+    };
 
 private:
     static const QString helpPageId;
 };
 
-
 class UserApplicationsSettingsPageState : public AppSettingsGUIPageState {
     Q_OBJECT
 public:
-    UserApplicationsSettingsPageState()
-        : openLastProjectFlag(false), askToSaveProject(0), enableStatistics(false),
-        tabbedWindowLayout(false), resetSettings(false), updatesEnabled(true) {}
+    UserApplicationsSettingsPageState() = default;
 
     QString translFile;
     QString style;
-    bool openLastProjectFlag;
-    int askToSaveProject;
-    bool enableStatistics;
-    bool tabbedWindowLayout;
-    bool resetSettings;
-    bool updatesEnabled;
+    bool openLastProjectFlag= false;
+    int askToSaveProject= 0;
+    bool enableStatistics = false;
+    bool tabbedWindowLayout = false;
+    bool resetSettings = false;
+    bool updatesEnabled = true;
+    bool experimentsEnabled = false;
+    bool isHighDpiAutoScalingDisabled = false;
 };
 
-
-class UserApplicationsSettingsPageWidget: public AppSettingsGUIPageWidget, public Ui_UserApplicationsSettingsWidget {
+class UserApplicationsSettingsPageWidget : public AppSettingsGUIPageWidget, public Ui_UserApplicationsSettingsWidget {
     Q_OBJECT
 public:
     UserApplicationsSettingsPageWidget(UserApplicationsSettingsPageController* ctrl);
 
-    virtual void setState(AppSettingsGUIPageState* state);
+    void setState(AppSettingsGUIPageState* state) override;
 
-    virtual AppSettingsGUIPageState* getState(QString& err) const;
+    AppSettingsGUIPageState* getState(QString& err) const override;
 
 private slots:
     void sl_transFileClicked();
+
+private:
+    /**
+     * @brief STYLE_KEYS_FIXED_REGISTER
+     * The bunch of "Appearance" with fixed register.
+     * The first value - the original name, produced by QStyleFactory::keys(), the second value - new name with fixed register.
+     * Note, that you can't replace any characters, only register could be changed
+     * (see here, https://doc.qt.io/qt-5/qstylefactory.html#details, "keys are case insensitive")
+     */
+    static const QMap<QString, QString> FIXED_CASE_QSTYLE_KEY_MAP;
 };
 
-}//namespace
+}  // namespace U2
 
-#endif
